pub struct ItemEffect {
pub spell_id: i32,
pub trigger_type: i32,
pub charges: i32,
pub cooldown: i32,
pub category_cooldown: i32,
}Fields
spell_id: i32trigger_type: i32charges: i32cooldown: i32category_cooldown: i32Trait Implementations
Sourceimpl Clone for ItemEffect
impl Clone for ItemEffect
Sourcefn clone(&self) -> ItemEffect
fn clone(&self) -> ItemEffect
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ItemEffect
impl Debug for ItemEffect
Sourceimpl<'de> Deserialize<'de> for ItemEffect
impl<'de> Deserialize<'de> for ItemEffect
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ItemEffect> for JsValuewhere
ItemEffect: Serialize,
impl From<ItemEffect> for JsValuewhere
ItemEffect: Serialize,
Sourcefn from(value: ItemEffect) -> Self
fn from(value: ItemEffect) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for ItemEffectwhere
Self: DeserializeOwned,
impl FromWasmAbi for ItemEffectwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for &ItemEffectwhere
ItemEffect: Serialize,
impl IntoWasmAbi for &ItemEffectwhere
ItemEffect: Serialize,
Sourceimpl IntoWasmAbi for ItemEffectwhere
ItemEffect: Serialize,
impl IntoWasmAbi for ItemEffectwhere
ItemEffect: Serialize,
Sourceimpl JsonSchema for ItemEffect
impl JsonSchema for ItemEffect
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for ItemEffectwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for ItemEffectwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for ItemEffectwhere
ItemEffect: Serialize,
impl OptionIntoWasmAbi for ItemEffectwhere
ItemEffect: Serialize,
Sourceimpl PartialEq for ItemEffect
impl PartialEq for ItemEffect
Sourceimpl RefFromWasmAbi for ItemEffectwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for ItemEffectwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<ItemEffect>
type Anchor = SelfOwner<ItemEffect>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for ItemEffect
impl Serialize for ItemEffect
Sourceimpl Tsify for ItemEffect
impl Tsify for ItemEffect
const DECL: &'static str = "export interface ItemEffect {\n spell_id: number;\n trigger_type: number;\n charges: number;\n cooldown: number;\n category_cooldown: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for ItemEffectwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for ItemEffectwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for ItemEffectwhere
ItemEffect: Serialize,
impl VectorIntoWasmAbi for ItemEffectwhere
ItemEffect: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribe for ItemEffect
impl WasmDescribe for ItemEffect
Sourceimpl WasmDescribeVector for ItemEffect
impl WasmDescribeVector for ItemEffect
impl StructuralPartialEq for ItemEffect